@@ -41,6 +41,7 @@
 #include "version.h" 
 #include "debug.h"
 #include "platform.h"
+#include "script.h"
 
 #include <stdio.h> 
 #include <ClanLib/lua.h>
@@ -84,16 +85,18 @@ int U61_Application::main(int argc, char **argv)
   int retcode=0;
   char buf[U61_CONST_STRING_SIZE];
 
+  CL_SetupCore::init();
+  U61_Debug::init();
+
   if (process_options(argc,argv))
     {
-      CL_SetupCore::init();
       CL_SetupDisplay::init();
       CL_SetupSound::init();
       CL_SetupNetwork::init();
       CL_SetupMikMod::init();
-      CL_Lua::open();
+      U61_Script::open();
+      U61_Platform::init();
 
-      U61_Debug::init();
       U61_Version::get_version_text(buf);
       U61_LOG_MESSAGE("Starting "<<buf<<"...");
 
@@ -119,15 +122,19 @@ int U61_Application::main(int argc, char **argv)
 	}
 
       U61_LOG_MESSAGE("Game over...");
-      U61_Debug::deinit();
 
-      CL_Lua::close();
+      U61_Platform::deinit();
+      U61_Script::close();
       CL_SetupMikMod::deinit();
       CL_SetupNetwork::deinit();    
       CL_SetupSound::deinit();
       CL_SetupDisplay::deinit();
-      CL_SetupCore::deinit();
     }
+  
+  U61_Debug::display_close_message();
+
+  U61_Debug::deinit();
+  CL_SetupCore::deinit();
 
   return retcode;
 }
@@ -152,42 +159,42 @@ bool U61_Application::process_options(int argc,char **argv)
 	    {
 	    case 'v':
 	      U61_Version::get_version_text(buf);
-	      cout<<buf<<"\n";
+	      std::cout<<buf<<"\n";
 	      result=false;
 	      break;
-	    case '?':
+	    case '?': 
 	    case 'h':
 	      U61_Version::get_version_text(buf);
-	      cout<<"\n";
-	      cout<<"U61 - another block-based game\n";
-	      cout<<"\n";
-	      cout<<"v"<<buf<<" compiled on "<<__DATE__<<" at "__TIME__"\n";
-	      cout<<"Copyright (C) 2000-2001 Christian Mauduit\n";
-	      cout<<"\n";
-	      cout<<"This program is free software; you can redistribute it and/or modify\n";
-	      cout<<"it under the terms of the GNU General Public License as published by\n";
-	      cout<<"the Free Software Foundation; either version 2 of the License, or\n";
-	      cout<<"(at your option) any later version.\n";
-	      cout<<"\n";
+	      std::cout<<"\n";
+	      std::cout<<"U61 - another block-based game\n";
+	      std::cout<<"\n";
+	      std::cout<<"v"<<buf<<" compiled on "<<__DATE__<<" at "__TIME__"\n";
+	      std::cout<<"Copyright (C) 2000-2001 Christian Mauduit\n";
+	      std::cout<<"\n";
+	      std::cout<<"This program is free software; you can redistribute it and/or modify\n";
+	      std::cout<<"it under the terms of the GNU General Public License as published by\n";
+	      std::cout<<"the Free Software Foundation; either version 2 of the License, or\n";
+	      std::cout<<"(at your option) any later version.\n";
+	      std::cout<<"\n";
 
-	      cout<<"This program is distributed in the hope that it will be useful,\n";
-	      cout<<"but WITHOUT ANY WARRANTY; without even the implied warranty of\n";
-	      cout<<"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n";
-	      cout<<"GNU General Public License for more details.\n";
+	      std::cout<<"This program is distributed in the hope that it will be useful,\n";
+	      std::cout<<"but WITHOUT ANY WARRANTY; without even the implied warranty of\n";
+	      std::cout<<"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n";
+	      std::cout<<"GNU General Public License for more details.\n";
 
-	      cout<<"\n";
-	      cout<<"You should have received a copy of the GNU General Public License\n";
-	      cout<<"along with this program; if not, write to the Free Software\n";
-	      cout<<"Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n";
-	      cout<<"\n";
-	      cout<<"Documentation is available in HTML, ascii text, PostScript, PDF... Read it 8-)\n";
-	      cout<<"\n";
-	      cout<<"U61 homepage   : http://www.ufoot.org/u61\n";
-	      cout<<"Contact author : ufoot@ufoot.org\n";
+	      std::cout<<"\n";
+	      std::cout<<"You should have received a copy of the GNU General Public License\n";
+	      std::cout<<"along with this program; if not, write to the Free Software\n";
+	      std::cout<<"Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n";
+	      std::cout<<"\n";
+	      std::cout<<"Documentation is available in HTML, ascii text, PostScript, PDF... Read it 8-)\n";
+	      std::cout<<"\n";
+	      std::cout<<"U61 homepage   : http://www.ufoot.org/u61\n";
+	      std::cout<<"Contact author : ufoot@ufoot.org\n";
 	      result=false;
 	      break;
 	    default:
-	      cout<<"Unknown option '"<<c<<"' \n";
+	      std::cout<<"Unknown option '"<<c<<"' \n";
 	      result=false;
 	      break;
 	    }
