@@ -89,6 +89,7 @@ void U61_Edit::update()
   strcpy(buffer,name);
   strcat(buffer,U61_MENUITEM_SEPARATOR);
   strcat(buffer,value);
+  strcat(buffer," ");
 
   set_text(buffer);
 }
@@ -117,11 +118,7 @@ bool U61_Edit::action(int key)
       pos--;
       break;
     case CL_KEY_DELETE:
-      if (pos>=len && pos>0)
-	{
-	  pos--;
-	}
-      if (len>0)
+      if (pos<len && len>0)
 	{
 	  suppress();
 	  changed=true;
@@ -135,24 +132,63 @@ bool U61_Edit::action(int key)
 	  changed=true;
 	}
       break;
+    case CL_KEY_HOME:
+      if (pos>0)
+	{
+	  pos=0;
+	  changed=true;
+	}
+      break;
+    case CL_KEY_END:
+      if (pos<len)
+	{
+	  pos=len;
+	  changed=true;
+	}
+      break;
+      /*
+       * we trap UP, DOWN and ENTER for these should not generate any key
+       */
     case CL_KEY_UP:
     case CL_KEY_DOWN:
+    case CL_KEY_ENTER:
+      /*
+       * we trap the modifiers keys, for we do not want them to interfere
+       */
+    case CL_KEY_LSHIFT:
+    case CL_KEY_RSHIFT:
+    case CL_KEY_ALTGR:
+    case CL_KEY_CAPSLOCK:
+    case CL_KEY_NUMLOCK:
       break;
+
+      /*
+       * Here, a "real" key has been typed
+       */
     default:
-      ascii=U61_Global::input_monitor.to_ascii(key);
-      if (isalnum(ascii) 
-	  || ascii==' ' 
-	  || ascii=='.' 
-	  || ascii=='-')
+      ascii=translate_to_ascii(key);
+      /*
+       * We exclude non-ascii characters
+       */
+      if (ascii>=32 && ascii<=127) 
 	{
-	  for (i=len;i>=pos;--i)
+	  /*
+	   * little hack: we forbid spaces at the beginning of the string.
+	   * this is a small hack which should avoid some (minor) problems,
+	   * when resolving the server name for instance
+	   */
+	  if (ascii!=' ' || pos>0)
 	    {
-	      value[i+1]=value[i];
+	      for (i=len;i>=pos;--i)
+		{
+		  value[i+1]=value[i];
+		}
+	      
+	      value[pos]=ascii;
+	      value[U61_EDIT_MAX_SIZE]=0;
+	      pos++;
+	      changed=true;
 	    }
-	  value[pos]=ascii;
-	  value[U61_EDIT_MAX_SIZE]=0;
-	  pos++;
-	  changed=true;
 	}
       break;
     }
@@ -221,24 +257,36 @@ void U61_Edit::select()
    * We select the char which is under the cursor
    */
   len=strlen(value);
-  if (pos<len)
+  /*
+   * Note the len+1 since we add a tailing space systematically,
+   * in case the cursor is at the end of the string
+   */
+  if (pos<len+1)
     {
       sel+=pos; 
       select_char(sel);
       blink_char(sel);
     }
-  else
+}
+
+
+/*--------------------------------------------------------------------------*/
+/*
+ * translate a key code to an ascii code. This function is virtual,
+ * therefore sub-classes might decide to block some characters and/or
+ * change the general behavior of the keyboard.
+ */
+int U61_Edit::translate_to_ascii(int key)
+{
+  int ascii;
+
+  ascii=U61_Global::input_monitor.to_ascii(key);
+  if (ascii==U61_KEYDEF_ASCII_UNKNOWN)
     {
-      /*
-       * if we are at the end of the string, then we make the last char
-       * dance, but we do not set it blinking
-       */
-      if (len>0)
-	{
-	  sel+=len-1;
-	  select_char(sel);
-	}
-    }
+      ascii=' ';
+    }  
+
+  return ascii;
 }
 
 
@@ -251,7 +299,3 @@ void U61_Edit::select()
 
 
 
-
-
-
-
