@@ -74,6 +74,9 @@
 #define U61_EVENT_REQUEST_CURSE     18
 #define U61_EVENT_DO_CURSE          19
 
+#define U61_EVENT_HISTORY_BEGIN     20
+#define U61_EVENT_HISTORY_END       21
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
