@@ -136,8 +136,6 @@ bool U61_Game::init(char *filename)
 	(U61_Global::config.data_file);
     }
 
-  U61_Global::data.chdir_to_data_dir();
-  
   if (success)
     {
       success=success && 
@@ -154,6 +152,7 @@ bool U61_Game::init(char *filename)
   if (success)
     {
       U61_Global::input_monitor.init();
+      U61_Global::input_monitor.read_config(&U61_Global::config);
     }
 
   return success;
@@ -165,11 +164,10 @@ bool U61_Game::init(char *filename)
  */
 void U61_Game::deinit()
 {
+  U61_Global::input_monitor.write_config(&U61_Global::config);
   U61_Global::config.write();
   
   U61_Global::data.unload();
-  
-  U61_Global::data.chdir_to_initial_dir();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -183,6 +181,7 @@ void U61_Game::run()
   int done_for_this_display;
   bool last_display_too_slow;
   U61_Menu *exit_menu;
+  int nb_pl;
 
   state=U61_GAME_STATE_RUN;
   slow_down_allowed=true;
@@ -223,6 +222,8 @@ void U61_Game::run()
    */
   while (state==U61_GAME_STATE_RUN) 
     {
+      nb_pl=nb_active_players();
+
       /*
        * we perform calls to the logic function, but we don't
        * call it more than "max_logic_per_display" times
@@ -236,6 +237,10 @@ void U61_Game::run()
 	  poll();
 	  logic();
 	  U61_Time::acknowledge_logic();
+	  if (nb_pl>0)
+	    {
+	      U61_Global::system_info.register_logic();
+	    }
 	  done_for_this_display++;
         }
 
@@ -278,9 +283,11 @@ void U61_Game::run()
       while (!U61_Time::is_display_needed(U61_Global::config.max_fps))
 	{
 	  U61_Time::idle();
+	  U61_Global::system_info.register_idle();
 	  poll();
 	}
       U61_Time::acknowledge_display();
+      U61_Global::system_info.register_display();
       display();
       poll();
 
@@ -398,6 +405,14 @@ void U61_Game::display()
       current_menu->draw();
     }
 
+  /*
+   * we draw the system information if needed
+   */
+  if (U61_Global::config.show_system_info)
+    {
+      U61_Global::system_info.draw();
+    }
+
   /*
    * It's wise to clean up those things regularly
    */
@@ -474,13 +489,26 @@ void U61_Game::network()
 
   if (protocol!=NULL)
     {
+      protocol->check_connection();
+
       if (protocol->send_all()==U61_PROTOCOL_FAILED 
 	  || protocol->recv_all()==U61_PROTOCOL_FAILED)
 	{
 	  protocol->print_diagnostic();
+	  if (protocol->is_connecting())
+	    {
+	      stop();
+
+	      /*
+	       * We go back of 2 levels in the menu history to get back
+	       * to the "join menu"
+	       */
+	      parent_menu();
+	      parent_menu();
+	    }
 	}
-      protocol->check_connection();
     }
+
   if (dispatcher!=NULL)
     {
       dispatcher->process();
@@ -509,6 +537,27 @@ void U61_Game::network()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Goes back of 1 level in the menu structure
+ */
+void U61_Game::parent_menu()
+{
+  U61_Menu *next_menu;
+
+  next_menu=current_menu->get_parent();
+
+  if (next_menu==NULL)
+    {
+      quit();
+    }
+  else
+    {
+      delete current_menu;      
+      current_menu=next_menu;
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the current menu. Usefull when one wants to call pop_menu,
@@ -576,8 +625,10 @@ void U61_Game::start_local_alone()
   int num;
 
   U61_LOG_DEBUG("local alone game started");
-  if (standard_init())
+  if (standard_init() && U61_Global::config.load_script())
     {
+      U61_Script::check_id();
+
       slow_down_allowed=true;
 
       dispatcher=new U61_LocalDispatcher();
@@ -602,8 +653,10 @@ void U61_Game::start_local_multiplayer()
 {
   int num0,num1,num2,num3;
   U61_LOG_DEBUG("local multiplayer game started");
-  if (standard_init())
+  if (standard_init() && U61_Global::config.load_script())
     {
+      U61_Script::check_id();
+
       slow_down_allowed=true;
 
       dispatcher=new U61_LocalDispatcher();
@@ -616,7 +669,32 @@ void U61_Game::start_local_multiplayer()
       num1=get_local_player(1);
       if (num1<0)
         {
-	  U61_Global::layout.init_multiplayer_1(&(player[0]));
+	  /*
+	   * If there's only 1 active player, we get player 0 or 1
+	   * depending on which one was the first
+	   */
+	  if (num0==0)
+	    {
+	      /*
+	       * The player 0 is the one that has been selected, so
+	       * we use 1 as an oponent
+	       */
+	      num1=1;
+	    }
+	  else
+	    {
+	      /*
+	       * player 0 was not selected, we him as the opponent
+	       */
+	      num1=0;
+	    }
+
+	  player[1].init_local(&(player_input[num1]),dispatcher,
+			       1,0,
+			       &(U61_Global::config.player[num1]));
+
+	  U61_Global::layout.init_multiplayer_2(&(player[0]),
+						&(player[1]));
         }
       else
         {
@@ -671,8 +749,10 @@ void U61_Game::start_network_new()
   U61_ServerDispatcher *d;
 
   U61_LOG_DEBUG("new network game started");
-  if (standard_init())
+  if (standard_init() && U61_Global::config.load_script())
     {
+      U61_Script::check_id();
+
       slow_down_allowed=false;
 
       d=new U61_ServerDispatcher();
@@ -731,7 +811,35 @@ void U61_Game::start_network_join()
       protocol=new U61_ClientProtocol(d,
 				      U61_Global::config.network_port,
                                       U61_Global::config.network_channel,
-                                      U61_Global::config.server_id);
+                                      U61_Global::config.server_id,
+				      false);
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * joins an existing network game by broadcasting a LAN
+ */
+void U61_Game::start_network_broadcast()
+{
+  U61_ClientDispatcher *d;
+
+  U61_LOG_DEBUG("broadcasting network game");
+  
+  if (standard_init() && U61_Global::config.load_script())
+    {
+      U61_Script::check_id();
+
+      slow_down_allowed=false;
+
+      d=new U61_ClientDispatcher();
+      dispatcher=d;     
+
+      protocol=new U61_ClientProtocol(d,
+				      U61_Global::config.network_port,
+                                      U61_Global::config.network_channel,
+                                      U61_Global::config.server_id,
+				      true);
     }
 }
 
@@ -748,7 +856,10 @@ void U61_Game::do_network_join(char *script,
   int num0,num1;
 
   time_reset(time);
+
   U61_Script::do_string(script);
+  U61_Script::check_id();
+
   initial_speed=speed;
   acceleration=accel;
   curse_delay=delay;
@@ -789,12 +900,16 @@ void U61_Game::stop_network()
 {
   if (protocol!=NULL)
     {
+      U61_LOG_DEBUG("deleting protocol");
       delete protocol;
+      U61_LOG_DEBUG("protocol deleted");
       protocol=NULL;
     }
   if (dispatcher!=NULL)
     {
+      U61_LOG_DEBUG("deleting dispatcher");
       delete dispatcher;
+      U61_LOG_DEBUG("dispatcher deleted");
       dispatcher=NULL;
     }
 }
@@ -844,8 +959,6 @@ bool U61_Game::standard_init()
   
   U61_Global::score.reset();
 
-  ok=ok && U61_Global::config.load_script();
-
   return ok;
 }
 
@@ -1038,6 +1151,26 @@ bool U61_Game::exists_player_id(int player_id)
   return result;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the number of active players
+ */
+int U61_Game::nb_active_players()
+{
+  int i;
+  int result=0;
+
+  for (i=0;i<U61_LAYOUT_NB_PLAYERS_TOTAL;++i)
+    {
+      if (player[i].is_available() && player[i].is_active())
+	{
+	  ++result;
+	}
+    }
+
+  return result;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * Returns the player associated to a given id
