@@ -88,6 +88,7 @@ class U61_Game
   void start_local_multiplayer();
   void start_network_new();
   void start_network_join();
+  void start_network_broadcast();
   void do_network_join(char *script,
 		       int id0,int id1,
 		       int speed,int accel,int delay,
@@ -129,9 +130,12 @@ class U61_Game
   void logic();
   void network();
 
+  void parent_menu();
+
   int find_free_player_id(int start, int step);
   int find_free_network_slot();
   bool exists_player_id(int player_id);
+  int nb_active_players();
 
   U61_Menu *current_menu;
 
