@@ -53,6 +53,7 @@
 #include "remotescript.h"
 #include "inputmonitor.h"
 #include "score.h"
+#include "systeminfo.h"
 
 /*---------------------------------------------------------------------------
  classes
@@ -68,6 +69,7 @@ public:
     static U61_RemoteScript remote_script;
     static U61_InputMonitor input_monitor;
     static U61_Score score;
+    static U61_SystemInfo system_info;
 protected:
 };
 
