@@ -42,6 +42,7 @@
 #include "global.h"
 #include "button.h"
 #include "utils.h"
+#include "toggle.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -64,7 +65,10 @@ U61_GraphicsMenu::U61_GraphicsMenu(U61_Menu *parent,
 
   add_item(new U61_Button("Toggle fullscreen"));
   add_item(new U61_Number("Max frames per sec",
-             &(conf->max_fps),5,50));
+			  &(conf->max_fps),5,50));
+  add_item(new U61_Toggle("Display system info",
+			  &(conf->show_system_info),
+			  "yes","no"));
 
   select(0);
 }
