@@ -233,7 +233,7 @@ void U61_LayoutItem::draw()
 {
   char buffer[U61_CONST_STRING_SIZE];
   U61_Player *target;
-  int i=0;
+  int i;
 
   /*
    * Now se set the layoutitem to "unchanged" since it has been drawn at least
@@ -278,6 +278,7 @@ void U61_LayoutItem::draw()
         	 buffer);
 	    }
 
+	  i=0;
 	  buffer[0]=0;
 	  while (i<U61_LAYOUTITEM_LIMIT_CURSE/2 && i<player->get_nb_curse(true))
 	    {
@@ -294,6 +295,7 @@ void U61_LayoutItem::draw()
 	     y_info+U61_Global::data.offset_curses_y[size],
 	     buffer);
 
+	  i=0;
 	  buffer[0]=0;
 	  while (i<U61_LAYOUTITEM_LIMIT_ANTIDOTE && i<player->get_nb_antidote())
 	    {
