@@ -68,7 +68,6 @@ public:
     void send_start_stop(int time);
     
 protected:
-    static const int DUMMY_DELAY=10;
     void poll_input();
     void poll_map();
     void poll_dispatcher();
@@ -83,7 +82,7 @@ protected:
     U61_Input *input;
     U61_Map *map;
 
-    char name[U61_STRING_SIZE];
+    char name[U61_CONST_STRING_SIZE];
 };
 
 #endif
