@@ -75,8 +75,8 @@ U61_Number::U61_Number(char *label, int *val,
  */
 void U61_Number::update()
 {
-    char buffer1[U61_STRING_SIZE];
-    char buffer2[U61_STRING_SIZE];
+    char buffer1[U61_CONST_STRING_SIZE];
+    char buffer2[U61_CONST_STRING_SIZE];
 
     /*
      * puts the number into a string
@@ -87,7 +87,7 @@ void U61_Number::update()
      * we want the text in the item to look like "blablabla is on"
      */
     strcpy(buffer1,name);
-    strcat(buffer1,SEPARATOR);
+    strcat(buffer1,U61_MENUITEM_SEPARATOR);
     strcat(buffer1,buffer2);
 
     /*
@@ -164,7 +164,7 @@ void U61_Number::select()
 {
     int start;
 
-    start=strlen(name)+strlen(SEPARATOR);
+    start=strlen(name)+strlen(U61_MENUITEM_SEPARATOR);
     
     select_right(start); 
 }
