@@ -55,9 +55,13 @@ class U61_Platform
   static char *get_data_path();
 
  public:
+  static void init();
+  static void deinit();
+
   static char *getcwd();
   static void chdir(char *dir);
   static void keep_dir_only(char *path);
+  static void keep_file_only(char *path);
 
   static char *get_builtin_theme_path();
   static char *get_builtin_script_path();
