@@ -52,10 +52,12 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <syslog.h>
+#include <signal.h>
 
 #include "platform.h"
 #include "const.h"
 #include "debug.h"
+#include "script.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -108,6 +110,24 @@ static char *standard_paths[NB_STANDARD_PATHS]=
  functions
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * used for various UNIX related global initializations
+ */
+void U61_Platform::init()
+{
+  signal(SIGPIPE,SIG_IGN);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * used for various UNIX related global de-initializations
+ */
+void U61_Platform::deinit()
+{
+  
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the current working directory
@@ -158,6 +178,29 @@ void U61_Platform::keep_dir_only(char *path)
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * keeps the file only in a /dir1/dir2/path.ext string
+ */
+void U61_Platform::keep_file_only(char *path)
+{
+  int pos;
+  bool found=false;
+  char tmp[U61_CONST_STRING_SIZE];
+
+  pos=strlen(path);
+  while (pos>=0 && !found)
+    {
+      if (path[pos]=='/')
+	{
+	  strcpy(tmp,path+pos+1);
+	  strcpy(path,tmp);
+	  found=true;
+	}
+      pos--;
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the user path (/home/ufoot/.u61/ for instance)
@@ -466,13 +509,15 @@ void U61_Platform::exec(char *file)
   int len;
 
   U61_LOG_MESSAGE("Restarting...");
-  U61_Debug::deinit();
 
-  CL_Lua::close();
+  U61_Platform::deinit();
+  U61_Script::close();
   CL_SetupMikMod::deinit();
   CL_SetupNetwork::deinit();    
   CL_SetupSound::deinit();
   CL_SetupDisplay::deinit();
+
+  U61_Debug::deinit();
   CL_SetupCore::deinit();
 
   /*
