@@ -55,6 +55,7 @@
 #include "platform.h"
 #include "const.h"
 #include "debug.h"
+#include "script.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -225,6 +226,24 @@ void _al_findclose(void *dta)
  functions
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * used for various windows related global initializations
+ */
+void U61_Platform::init()
+{
+
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * used for various windows related global de-initializations
+ */
+void U61_Platform::deinit()
+{
+  
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the current working directory
@@ -275,6 +294,29 @@ void U61_Platform::keep_dir_only(char *path)
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * keeps the file only in a /dir1/dir2/path.ext string
+ */
+void U61_Platform::keep_file_only(char *path)
+{
+  int pos;
+  bool found=false;
+  char tmp[U61_CONST_STRING_SIZE];
+
+  pos=strlen(path);
+  while (pos>=0 && !found)
+    {
+      if (path[pos]=='\\' || path[pos]=='/')
+	{
+	  strcpy(tmp,path+pos+1);
+	  strcpy(path,tmp);
+	  found=true;
+	}
+      pos--;
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the path where user data are stored, needs to be writeable
@@ -501,13 +543,15 @@ void U61_Platform::exec(char *file)
   //  int len;
 
   U61_LOG_MESSAGE("Restarting...");
-  U61_Debug::deinit();
 
-  CL_Lua::close();
+  U61_Platform::deinit();
+  U61_Script::close();
   CL_SetupMikMod::deinit();
   CL_SetupNetwork::deinit();    
   CL_SetupSound::deinit();
   CL_SetupDisplay::deinit();
+
+  U61_Debug::deinit();
   CL_SetupCore::deinit();
 
   /*
