@@ -40,9 +40,10 @@
 #include "playerinput.h"
 
 /*---------------------------------------------------------------------------
- globals
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_PLAYERINPUT_NB_KEYS        10
 
 /*---------------------------------------------------------------------------
  functions
@@ -52,7 +53,7 @@
 /* 
  * creation of a menu input object
  */ 
-U61_PlayerInput::U61_PlayerInput() : U61_Input(NB_KEYS)
+U61_PlayerInput::U61_PlayerInput() : U61_Input(U61_PLAYERINPUT_NB_KEYS)
 {
     //init();
 }
@@ -72,43 +73,43 @@ U61_PlayerInput::~U61_PlayerInput()
 void U61_PlayerInput::init(U61_PlayerConfig *config)
 {
     set_key(0,U61_Key(config->key_start_stop,
-                      U61_Event::START_STOP,
-                      U61_Key::NO_REPEAT,
-                      U61_Key::NO_REPEAT));
+                      U61_EVENT_START_STOP,
+                      U61_KEY_NO_REPEAT,
+                      U61_KEY_NO_REPEAT));
     set_key(1,U61_Key(config->key_move_left,
-                      U61_Event::MOVE_LEFT,
+                      U61_EVENT_MOVE_LEFT,
                       config->first_repeat_move,
                       config->standard_repeat_move));
     set_key(2,U61_Key(config->key_move_right,
-                      U61_Event::MOVE_RIGHT,
+                      U61_EVENT_MOVE_RIGHT,
                       config->first_repeat_move,
                       config->standard_repeat_move));
     set_key(3,U61_Key(config->key_rotate_left,
-                      U61_Event::ROTATE_LEFT,
+                      U61_EVENT_ROTATE_LEFT,
                       config->first_repeat_rotate,
                       config->standard_repeat_rotate));
     set_key(4,U61_Key(config->key_rotate_right,
-                      U61_Event::ROTATE_RIGHT,
+                      U61_EVENT_ROTATE_RIGHT,
                       config->first_repeat_rotate,
                       config->standard_repeat_rotate));
     set_key(5,U61_Key(config->key_move_down,
-                      U61_Event::MOVE_DOWN,
+                      U61_EVENT_MOVE_DOWN,
                       config->first_repeat_move,
                       config->standard_repeat_move));
     set_key(6,U61_Key(config->key_drop,
-                      U61_Event::DROP,
-                      U61_Key::NO_REPEAT,
-                      U61_Key::NO_REPEAT));
+                      U61_EVENT_DROP,
+                      U61_KEY_NO_REPEAT,
+                      U61_KEY_NO_REPEAT));
     set_key(7,U61_Key(config->key_next_victim,
-                      U61_Event::NEXT_VICTIM,
+                      U61_EVENT_NEXT_VICTIM,
                       config->first_repeat_other,
                       config->standard_repeat_other));
     set_key(8,U61_Key(config->key_prev_victim,
-                      U61_Event::PREV_VICTIM,
+                      U61_EVENT_PREV_VICTIM,
                       config->first_repeat_other,
                       config->standard_repeat_other));
     set_key(9,U61_Key(config->key_use_antidote,
-                      U61_Event::USE_ANTIDOTE,
+                      U61_EVENT_USE_ANTIDOTE,
                       config->first_repeat_other,
                       config->standard_repeat_other));
 }
