@@ -56,8 +56,6 @@
  constants
  ---------------------------------------------------------------------------*/
 
-#define U61_PROTOCOL_GAME_ID        "U61 by U-Foot"
-
 #define U61_PROTOCOL_DONE 0
 #define U61_PROTOCOL_LATER 1
 #define U61_PROTOCOL_FAILED 2
@@ -65,8 +63,8 @@
 #define U61_PROTOCOL_BEGIN 0
 #define U61_PROTOCOL_END -1
 
-#define U61_PROTOCOL_ID_SENT 20
-#define U61_PROTOCOL_ID_RECEIVED 21
+#define U61_PROTOCOL_PROGRAM_SENT 20
+#define U61_PROTOCOL_PROGRAM_RECEIVED 21
 #define U61_PROTOCOL_VERSION_SENT 22
 #define U61_PROTOCOL_VERSION_RECEIVED 23
 #define U61_PROTOCOL_READY_SENT 50
@@ -92,18 +90,21 @@ class U61_Protocol
   int send_all();
   int recv_all();
   void print_diagnostic();
+  bool is_connecting();
 
  protected:
+  bool connecting;
   int stage;
   int step;
   int port;
   int channel;
   std::string diagnostic;
+  bool failed;
 
   CL_NetSession *session;
 
-  int send_id(U61_Connection *conn);
-  int recv_id(U61_Connection *conn);
+  int send_program(U61_Connection *conn);
+  int recv_program(U61_Connection *conn);
   int send_version(U61_Connection *conn);
   int recv_version(U61_Connection *conn);
   int send_ready(U61_Connection *conn);
