@@ -53,11 +53,15 @@
 #include "utils.h"
 #include "debug.h"
 #include "global.h"
+#include "version.h"
+#include "script.h"
 
 /*---------------------------------------------------------------------------
  constants
  ---------------------------------------------------------------------------*/
 
+#define U61_SCRIPT_LUA_GET_PROGRAM "user_get_program"
+#define U61_SCRIPT_LUA_GET_VERSION "user_get_version"
 #define U61_SCRIPT_LUA_NEW_SHAPE "user_new_shape"
 #define U61_SCRIPT_LUA_DO_SHAPE "user_do_shape"
 #define U61_SCRIPT_LUA_ROTATE_LEFT "user_rotate_left"
@@ -156,6 +160,30 @@ static bool map_write=false;
  functions
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * initializes Lua. The reason we do not use the standard CL_Lua::init()
+ * function is that in recent versions of ClanLib, CL_Lua::init() initializes
+ * much more than Lua: it loads a bunch of libs including "lua bindings"
+ * which would allow the scripts to get an access to the screen and so on.
+ * And the use of these would represent a potential security hole for U61,
+ * since the scripts acan be obtained over Internet automatically without
+ * any check at all...
+ */
+void U61_Script::open()
+{
+  lua_open();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * De-initializes Lua
+ */
+void U61_Script::close()
+{
+  lua_close();
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * initializes the script module with a string
@@ -194,19 +222,25 @@ bool U61_Script::do_file(char *name)
 
   bSuccess=false;
 
-  //lua_open();
-  U61_LOG_DEBUG("Loading script from \""<<name<<"\".");
-  iResult=CL_Lua::dofile(name);
-  switch (iResult)
+  if (!U61_Utils::file_exists(name))
     {
-    case 0:
-      bSuccess=true;
-      break;
-    default:
-      U61_LOG_WARNING("Lua error reading script, code is "<<iResult<<".");
-      break;
+      U61_LOG_WARNING("Unable to load script from \""<<name<<"\" (file does not exist).");
     }
-  
+  else
+    {
+      U61_LOG_DEBUG("Loading script from \""<<name<<"\".");
+      iResult=CL_Lua::dofile(name);
+      switch (iResult)
+	{
+	case 0:
+	  bSuccess=true;
+	  break;
+	default:
+	  U61_LOG_WARNING("Lua error reading script, code is "<<iResult<<".");
+	  break;
+	}    
+    }
+
   U61_Global::data.chdir_to_data_dir();
 
   return bSuccess;
@@ -312,6 +346,113 @@ void U61_Script::secure_pointers()
   map_write=false;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * checks that the script is a correct U61 script
+ */
+bool U61_Script::check_id()
+{
+  bool success=true;
+  char *program_read;
+  char *version_read;
+  char version[U61_CONST_STRING_SIZE];
+
+  U61_Version::get_version_text(version);
+
+  program_read=get_program();
+  version_read=get_version();
+
+  if (program_read==NULL || strcmp(program_read,U61_CONST_PROGRAM))
+    {
+      success=false;
+      U61_LOG_WARNING("The script file does not seem to be a valid U61 script file, you should check that U61 is correctly installed.");
+    }
+  else
+    {  
+      if (version_read==NULL || strcmp(version_read,version))
+	{
+	  success=false;
+	  U61_LOG_WARNING("The script file version is \""<<version_read<<"\" but the game version is \""<<version<<"\", so you might get errors when playing. Maybe you should just get rid of it and/or reinstall U61.");
+	}
+    }
+
+  return success;    
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * calls the user defined function that returns the name of the program.
+ * It is used to check that the script is a valid Lua script
+ */
+char *U61_Script::get_program()
+{
+  static char result[U61_CONST_STRING_SIZE];
+  char *str=NULL;
+  lua_Object func,ret;
+
+  secure_pointers();
+
+  lua_beginblock();
+  
+  func=lua_getglobal(U61_SCRIPT_LUA_GET_PROGRAM);
+  if (lua_isfunction(func))
+    {
+      lua_callfunction(func);
+    }
+
+  ret=lua_getresult(1);
+  if (lua_isstring(ret))
+    {
+      str=lua_getstring(ret);
+    }
+
+  if (str==NULL)
+    {
+      str="???";
+    }
+  strcpy(result,str);
+  lua_endblock();
+
+  return (result);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * calls the user defined function that returns the name of the version.
+ * It is used to check that the script is a valid Lua script
+ */
+char *U61_Script::get_version()
+{
+  static char result[U61_CONST_STRING_SIZE];
+  char *str=NULL;
+  lua_Object func,ret;
+
+  secure_pointers();
+
+  lua_beginblock();
+  
+  func=lua_getglobal(U61_SCRIPT_LUA_GET_VERSION);
+  if (lua_isfunction(func))
+    {
+      lua_callfunction(func);
+    }
+
+  ret=lua_getresult(1);
+  if (lua_isstring(ret))
+    {
+      str=lua_getstring(ret);
+    }
+
+  if (str==NULL)
+    {
+      str="???";
+    }
+  strcpy(result,str);
+  lua_endblock();
+
+  return (result);
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * calls the user defined function that returns the code for the next block.
