@@ -84,6 +84,7 @@ bool U61_ServerDispatcher::open(U61_Connection *c)
   int i,j;
   bool ok=true;
   U61_Event evt;
+  int history_size;
 
   U61_LOG_MESSAGE("Opening connection");
   connection.push_back(c);
@@ -98,13 +99,49 @@ bool U61_ServerDispatcher::open(U61_Connection *c)
       if (history[i].playing())
 	{
           U61_LOG_DEBUG("Sending history for player "<<i<<"");
-          for (j=0;j<(int) history[i].size();++j)
+          history_size=(int) history[i].size();
+          if (history_size>0)
 	    {
-              evt=history[i].get(j);
-              if (!c->send(evt))
+              /*
+               * We get the first event in the history to prepare our
+               * HISTORY_BEGIN event. It's important, since we can not
+               * guess parameters such as time for instance.
+               */
+	      evt=history[i].get(0);
+	      evt.code=U61_EVENT_HISTORY_BEGIN;
+              evt.target=evt.author=i;
+              /*
+	       * Now we send our HISTORY_BEGIN event
+               */
+	      if (!c->send(evt))
 		{
-                  ok=false;
-		}  
+		  ok=false;
+		}
+              /*
+               * Now we send all the events, including the one we had
+               * used to prepare the special HISTORY_BEGIN event.
+               */
+	      for (j=0;j<history_size;++j)
+		{
+		  evt=history[i].get(j);
+		  if (!c->send(evt))
+		    {
+		      ok=false;
+		    }  
+		}
+              /*
+               * Now we send the HISTORY_END event to mark the fact
+               * that the history is done. It's important, since during
+               * the transmission/interpretation of a long history,
+               * we do not want any display, but when the history is done,
+               * one must turn the map display back on.
+               */
+	      evt.code=U61_EVENT_HISTORY_END;
+              evt.target=evt.author=i;
+	      if (!c->send(evt))
+		{
+		  ok=false;
+		}
 	    }
 	}
     }
