@@ -179,13 +179,13 @@ int U61_ServerProtocol::send_next_packet()
 	}
       break;
     case U61_SERVERPROTOCOL_CLIENT_ACCEPTED:
-      if ((result=send_id(connection[new_connection]))==U61_PROTOCOL_DONE)
+      if ((result=send_program(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
-	  stage=U61_PROTOCOL_ID_SENT;
-	  U61_LOG_DEBUG("stage=ID_SENT");
+	  stage=U61_PROTOCOL_PROGRAM_SENT;
+	  U61_LOG_DEBUG("stage=PROGRAM_SENT");
 	}
       break;
-    case U61_PROTOCOL_ID_RECEIVED:
+    case U61_PROTOCOL_PROGRAM_RECEIVED:
       if ((result=send_version(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
 	  stage=U61_PROTOCOL_VERSION_SENT;
@@ -263,7 +263,7 @@ int U61_ServerProtocol::send_next_packet()
       break;
     }
 
-  handle_error(result);
+  handle_error(&result);
 
   return result;
 }
@@ -287,11 +287,11 @@ int U61_ServerProtocol::recv_next_packet()
 	  U61_LOG_DEBUG("stage=CLIENT_ACCEPTED");
 	}
       break;
-    case U61_PROTOCOL_ID_SENT:
-      if ((result=recv_id(connection[new_connection]))==U61_PROTOCOL_DONE)
+    case U61_PROTOCOL_PROGRAM_SENT:
+      if ((result=recv_program(connection[new_connection]))==U61_PROTOCOL_DONE)
 	{
-	  stage=U61_PROTOCOL_ID_RECEIVED;
-	  U61_LOG_DEBUG("stage=ID_RECEIVED");
+	  stage=U61_PROTOCOL_PROGRAM_RECEIVED;
+	  U61_LOG_DEBUG("stage=PROGRAM_RECEIVED");
 	}
       break;
     case U61_PROTOCOL_VERSION_SENT:
@@ -310,7 +310,7 @@ int U61_ServerProtocol::recv_next_packet()
       break;
     }
 
-  handle_error(result);
+  handle_error(&result);
 
   return result;
 }
@@ -326,7 +326,7 @@ int U61_ServerProtocol::start_listening()
 
   try 
     {
-      session=new CL_NetSession(U61_PROTOCOL_GAME_ID,port);
+      session=new CL_NetSession(U61_CONST_PROGRAM,port);
     }
   catch (CL_Error e)
     {
@@ -446,8 +446,11 @@ int U61_ServerProtocol::send_script()
   int c;
   int pos=0;
 
+  U61_Global::data.chdir_to_initial_dir();
+
   strncpy(script_name,U61_Global::config.script_file,sizeof(script_name)-1);
-  f=fopen(script_name,"rb");
+
+  f=fopen(script_name,"r");
   if (f!=NULL)
     {
       while ((c=fgetc(f))!=EOF && pos<U61_CONST_SCRIPT_SIZE)
@@ -462,12 +465,16 @@ int U61_ServerProtocol::send_script()
     }
   else
     {
+      U61_LOG_WARNING("Unable to open \""<<script_name<<"\".");
+
       diagnostic="Could not open script file \"";
       diagnostic+=script_name;
       diagnostic+="\"";
       result=U61_PROTOCOL_FAILED;
     }
 
+  U61_Global::data.chdir_to_data_dir();
+
   return result;
 }
 
@@ -582,15 +589,28 @@ int U61_ServerProtocol::send_time()
  * Checks the return value of send & recv functions
  * stops everything if something's going wrong
  */
-void U61_ServerProtocol::handle_error(int result)
+void U61_ServerProtocol::handle_error(int *result)
 {
-  if (result==U61_PROTOCOL_FAILED)
+  if ((*result)==U61_PROTOCOL_FAILED)
     {
       U61_LOG_WARNING("Network server protocol error on connection "
 		      <<new_connection
 		      <<" at stage "
 		      <<stage);
 
+      if (stage!=U61_PROTOCOL_BEGIN)
+	{
+	  /*
+	   * For all the errors except the impossibility to bind the
+	   * listening socket (which can only happen at stage 
+	   * U61_PROTOCOL_BEGIN), we decide to mask the error and
+	   * replace it by U61_PROTOCOL_LATER. This is because we do not
+	   * want the whole server connections to be closed only because
+	   * of a single little problem on one channel...
+	   */
+	  (*result)=U61_PROTOCOL_LATER;
+	}
+
       if (new_connection>=0 && connection[new_connection]!=NULL)
 	{
 	  delete connection[new_connection];
