@@ -47,7 +47,6 @@
  ---------------------------------------------------------------------------*/
 
 #define U61_TIME_TIME_UNIT         10
-#define U61_TIME_IDLE_DELAY         5
  
 /*--------------------------------------------------------------------------*/
 /*
@@ -358,6 +357,6 @@ int U61_Time::system_time()
  */
 void U61_Time::idle()
 {
-  CL_System::sleep(U61_TIME_IDLE_DELAY);
+  CL_System::sleep(U61_TIME_IDLE_DELAY*U61_TIME_TIME_UNIT);
   U61_LOG_DEBUG("game is idle");
 }
