@@ -125,3 +125,23 @@ bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
 
   return ok;
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Returns true if the file exists
+ */
+bool U61_Utils::file_exists(char *filename)
+{
+  FILE *f;
+  bool exists=false;
+
+  f=fopen(filename,"r");
+  
+  if (f!=NULL)
+    {
+      exists=true;
+      fclose(f);
+    }
+  
+  return exists;
+}
